import { Box, Button, Modal, Typography, Divider, Grid } from "@mui/material";
import { RootState } from "../../../redux/store/store";
import { useSelector } from "react-redux";
import { useEffect, useState } from "react";
import CloseIcon from "@mui/icons-material/Close";

type Props = {
	open: boolean;
	setViewModal: Function;
	id?: string;
};

const mainContainerStyle = {
	position: "absolute",
	top: "50%",
	left: "50%",
	transform: "translate(-50%, -50%)",
	// width: "544px",
	// height: "190px",
	gap: "8px",
	bgcolor: "background.paper",
	borderRadius: 2,
	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
	p: 4,
	display: "flex",
	flexDirection: "column",
	alignItems: "center",
};

const headerLayoutStyle = {
	// width: 544,
	// height: 48,
	gap: "24px",
	paddingBottom: "12px",
	display: "flex",
	alignItems: "center",
	justifyContent: "space-between",
};

export default function ViewModal({ open, setViewModal, id }: Props) {
	const { admins } = useSelector((state: RootState) => state.adminReducer);
	const [selectedAdmin, setSelectedAdmin] = useState<any>(null);

	useEffect(() => {
		if (id) {
			const admin = admins.find((admin) => admin.id === id);
			setSelectedAdmin(admin);
		}
	}, [id, admins]);

	return (
		<Modal
			open={open}
			aria-labelledby="modal-title"
			aria-describedby="modal-description"
		>
			<Box sx={mainContainerStyle}>
				<Box sx={headerLayoutStyle}>
					<Typography
						id="modal-title"
						variant="h5"
						fontWeight="bold"
						sx={{ flex: 1, textAlign: "center" }}
					>
						{selectedAdmin?.name}'s Details
					</Typography>
					<Box
						onClick={() => setViewModal(false)}
						sx={{
							cursor: "pointer",
							display: "flex",
							alignItems: "center",
							marginLeft: "auto", // Ensures the button is at the right end
							justifyContent:"flex-end"
						}}
					>
						<CloseIcon />
					</Box>
				</Box>

				<Divider sx={{ width: "100%" }} />

				{selectedAdmin ? (
					<Box
						sx={{
							width: "100%",
							textAlign: "left",
							display: "flex",
							flexDirection: "column",
							gap: 1.5,
							whiteSpace: "pre-wrap",
							wordBreak: "break-word",
							overflowWrap: "break-word",
						}}
					>
						<Grid container spacing={2}>
							<Grid item xs={6}>
								<Typography>
									<b>Name:</b>
								</Typography>
								<Typography>{selectedAdmin.name}</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography>
									<b>Phone:</b>
								</Typography>
								<Typography>{selectedAdmin.phone}</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography>
									<b>Email:</b>
								</Typography>
								<Typography>{selectedAdmin.email}</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography>
									<b>Address:</b>
								</Typography>
								<Typography>
									{selectedAdmin.registeredAddress ?? "N/A"}
								</Typography>
							</Grid>
						</Grid>
					</Box>
				) : (
					<Typography align="center">
						No admin found with this ID
					</Typography>
				)}
			</Box>
		</Modal>
	);
}
